@@ -1,8 +1,9 @@
 from .user import User
+from .poll import Poll
 from .wallet import Wallet
 from .collection import Collection
 from .user_wallet import UserWallet
-from .polls_queue import PollsQueue
+from .daily_claim import DailyClaim
 from .user_session import UserSession
 from .user_birthday import UserBirthday
 from .user_voicestate import UserVoiceState
\ No newline at end of file
